## 1.13.4 (2025-06-29)
### Bug fixes (3 changes)
- [fix duplicate elements in the home page history](https://gitlab.com/biolds1/sosse/-/commit/60d643604e270e490939a4a17d160925beb418e8) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/183))
- [fix passing SOSSE_DB_HOST to Docker setup](https://gitlab.com/biolds1/sosse/-/commit/93dc9fc5f94707a9fb8a02786bf7e29c4ea680cc) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/183))
- [fix screenshot archive links pointing to source pages](https://gitlab.com/biolds1/sosse/-/commit/16330cb26826bbe3ca82bb748fa1bee487c0029c) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/183))

## 1.13.3 (2025-06-15)
### Bug fixes (1 change)
- [fix daily Docker image rebuild](https://gitlab.com/biolds1/sosse/-/commit/1baa0c80aabb83ccc5a8b897ac9152a725b1e055) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/181))

## 1.13.2 (2025-06-10)
### Bug fixes (1 change)
- [fix static files update during Docker upgrade](https://gitlab.com/biolds1/sosse/-/commit/0237c3307213895adb94fc6eadf302cab96ebaf3) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/180))

## 1.13.1 (2025-06-09)
### Bug fixes (1 change)
- [fix upgrading from Docker image 1.12](https://gitlab.com/biolds1/sosse/-/commit/13d1bf3991866f312e43b00ce63244b26307efa9) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/178))

## 1.13.0 (2025-06-05)
### Features (12 changes)
- [webhook triggering while crawling pages](https://gitlab.com/biolds1/sosse/-/commit/5cdc938acd02188d66995a2ebd641f8b6e2fa1bc) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/159))
- [docker-compose based setup](https://gitlab.com/biolds1/sosse/-/commit/88b13b620292420ca3592e7f4bdb8215696273fd) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/155))
- [document tags](https://gitlab.com/biolds1/sosse/-/commit/2bda03fe36f4fb6a67ff8b18981deac31a654ea2) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/164))
- [search result CSV export](https://gitlab.com/biolds1/sosse/-/commit/604e7fce82d906deaf4c81c8b35dd6052d71f910) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/176))
- [minimize database queries when workers are idle](https://gitlab.com/biolds1/sosse/-/commit/9b117e0cb1ecd1249840369924f3970cec3fc25f) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/168))
- [remove the word stats button](https://gitlab.com/biolds1/sosse/-/commit/eefc0c0b981b22ea7916a1f7b9261247fc936068) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/164))
- [use the script field of Crawl Policy to overwrite document's data](https://gitlab.com/biolds1/sosse/-/commit/c95a6149c1a6f54c094cd03f9a309e3d81b14b06) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/164))
- [set default policy to Crawl on depth](https://gitlab.com/biolds1/sosse/-/commit/dacae278a1601b633a23e933d922bc30ea9b70c6) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/164))
- [ask for confirmation when quitting a modified form](https://gitlab.com/biolds1/sosse/-/commit/3bdd529a167510539898207bb12b6660ffadbb90) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/159))
- [enable/disable search shortcuts](https://gitlab.com/biolds1/sosse/-/commit/dcc662d251cc06ade916c49bc6922dd9f064cd73) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/154))
- [add an option to force reprocessing pages when no change is detected](https://gitlab.com/biolds1/sosse/-/commit/0a515f8e214978995a77e0e675a82315589239de) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/153))
- [run crawlers using half of the available CPU cores by default](https://gitlab.com/biolds1/sosse/-/commit/e74f74ad06a01163ae78f2b5605a88a25fd76e38) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/150))
### Bug fixes (2 changes)
- [fix homepage links pointing to archive, when the should point to the source site](https://gitlab.com/biolds1/sosse/-/commit/9ccefe5c98212212cb58a5bd34aded4d6440f186) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/176))
- [fix handling meta elements redirects with Request](https://gitlab.com/biolds1/sosse/-/commit/a196961978848066afa07dd079761e93a1d3c9b2) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/168))

## 1.12.4 (2025-03-14)
### Bug fixes (1 change)
- [fix some parallel download failures using Firefox or Chromium](https://gitlab.com/biolds1/sosse/-/commit/600aae1ac85865a3f5b0759f685f9ef5071019e5) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/160))

## 1.12.3 (2025-02-24)
### Bug fixes (1 change)
- [fix fake_useragent in the pypi package](https://gitlab.com/biolds1/sosse/-/commit/41be1cbdff6122c53e75a245020797ed3382b1df) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/156))

## 1.12.2 (2025-02-02)
### Bug fixes (1 change)
- [fix documentation build](https://gitlab.com/biolds1/sosse/-/commit/4537d229f64feb2ec5491d7bbd6ab91cc30165b8)

## 1.12.1 (2025-02-04)
### Bug fixes (3 changes)
- [fix counting doc with no language in the total count in analytics](https://gitlab.com/biolds1/sosse/-/commit/27b70b6bdb09a64fd74eb054d8fbc4a1f5a1946e) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/145))
- [fix displaying the 24h analytics graphs](https://gitlab.com/biolds1/sosse/-/commit/1bf06a874adf48edc049047741f8fef94df688fb) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/145))
- [fix docker build status when no upgrade is available](https://gitlab.com/biolds1/sosse/-/commit/26de1e90dbe3af5682ca2989ab61eb83f6903c8d)

## 1.12.0 (2025-01-30)
### Features (12 changes)
- [enable browser detection by default](https://gitlab.com/biolds1/sosse/-/commit/11e7d2ec898e46b2260ba191a5af338a482c8bd3) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/142))
- [disable recursion in the default Crawl Policy](https://gitlab.com/biolds1/sosse/-/commit/a60ee33972310edc540ed06f98762a9179918eac) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/142))
- [store the modification date of documents](https://gitlab.com/biolds1/sosse/-/commit/83dafdef263cd909b9fb9d07b7d3a86552e3f69b) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/142))
- [display preview of images document in search results](https://gitlab.com/biolds1/sosse/-/commit/a335a224b20dce7e10b706149a22c5ba14761215) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/140))
- [add an orphan filter to the Document admin](https://gitlab.com/biolds1/sosse/-/commit/e30f1c589dd1c11f44f39dbefa87b085bb353374) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/140))
- [batch URLs queueing](https://gitlab.com/biolds1/sosse/-/commit/3cf8313ff27e889edf5ac5c997afb7ef41d32ca7) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/139))
- [docker image daily upgrade](https://gitlab.com/biolds1/sosse/-/commit/994a8ddcd14ac5588c24838aaa0846d111cce2d8) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/138))
- [crawl status and crawlers info pages split](https://gitlab.com/biolds1/sosse/-/commit/bf973ff58765d23edb5460ea13c68826d47fd5c4) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/134))
- [crawl all mimetypes by default](https://gitlab.com/biolds1/sosse/-/commit/eca3f3ebca15535ae2b792e29c8f584b6bc8edc3) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/134))
- [add a mimetype charts in the analytics page](https://gitlab.com/biolds1/sosse/-/commit/1d58c5124dccab00b0c2e48c3ae00b35523e313d) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/132))
- [upgrade geckodriver to version 0.35](https://gitlab.com/biolds1/sosse/-/commit/1ef829b92e7ee734c8883478966629a689b9ac76) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/129))
- [customizable "show on homepage" value when crawling a new URL](https://gitlab.com/biolds1/sosse/-/commit/8cb1fa5bc28758f91245005b26e912785a152717) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/128))
### Bug fixes (5 changes)
- [fix loading CSS stylesheets that have rel="preload" attribute](https://gitlab.com/biolds1/sosse/-/commit/e44e91f47b1847870e06ba23ad426e414da012e4) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/142))
- [fix handling @import CSS directive](https://gitlab.com/biolds1/sosse/-/commit/40532b527988d6335d0f59fd5f0ecabad9c35a38) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/142))
- [fix cropped pages screenshots](https://gitlab.com/biolds1/sosse/-/commit/e5cd91eb50722ed9c683e6f84718fb500a60df03) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/140))
- [fix the unit of the last year indexing speed](https://gitlab.com/biolds1/sosse/-/commit/bb1166f9ab2f268cad2b4d2baa9fe32a6b7ae5e9) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/140))
- [fix path to admin's images](https://gitlab.com/biolds1/sosse/-/commit/7e1b8dbbd443376b0fe66dd3d390c64af6c9d87a) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/132))

## 1.11.1 (2024-12-26)
### Bug fixes (3 changes)
- [avoid an exception when showing a cached page being crawled](https://gitlab.com/biolds1/sosse/-/commit/b45a146b8c0b5ae883728ee12dbc93587df355f6) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/126))
- [prevent execution of scripts in cached pages](https://gitlab.com/biolds1/sosse/-/commit/7ad77cfca66f5d6213267f500117add242d7fd41) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/124))
- [fix saving some CSS stylesheets](https://gitlab.com/biolds1/sosse/-/commit/b675ca3295f13d1e0952fe801b36db2acb7d62bb) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/124))

## 1.11.0 (2024-12-09)
### Features (6 changes)
- [store file downloads](https://gitlab.com/biolds1/sosse/-/commit/395af4961c81c17a99a43922eaa8a0057571c9ea) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/121))
- [fake-useragent integration](https://gitlab.com/biolds1/sosse/-/commit/403d5f5cac623a0d91b17c65894e765932cadfd6) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/119))
- [home page optimization](https://gitlab.com/biolds1/sosse/-/commit/c0fa90de3c2a9cfdfe47069393e119d87ec05020) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/118))
- [multi-line url regexp in Crawl Policies](https://gitlab.com/biolds1/sosse/-/commit/28e544c98b0849b01d137f0e1a036e3e74a37ff6) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/117))
- [linkpreview integration](https://gitlab.com/biolds1/sosse/-/commit/b18219c890c4b770023556c6ec90d6e20be41436) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/116))
- [Netscape formatted cookies import](https://gitlab.com/biolds1/sosse/-/commit/dd4e9ab3702572c9704db172365ac2ca56ca16ea) ([ticket](https://github.com/biolds/sosse/issues/48))
### Bug fixes (1 change)
- [fix loading cookies for root url of domains](https://gitlab.com/biolds1/sosse/-/commit/aa16c509e48eab41759c55c8c3dd899ac7d4dd84)

## 1.10.1 (2024-09-16)
### Features (1 change)
- [allow setting configurations option via environment variables](https://gitlab.com/biolds1/sosse/-/commit/c03bd26e5bc5d3ac29d7f7a2579952a7e490b170) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/113))
### Bug fixes (3 changes)
- [fix running Chromium](https://gitlab.com/biolds1/sosse/-/commit/b6598316a898f72f3b23f2ba6118e39a5781891b) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/113))
- [fix Chromium file downloads](https://gitlab.com/biolds1/sosse/-/commit/73cb84ecf5ce394db281549c074b117ee80f43f4) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/113))
- [pin a Selenium version < 4.9 to prevent Selenium Manager to trigger](https://gitlab.com/biolds1/sosse/-/commit/f5f093c2c22bf102d45a621c4d5824b92e90abec) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/114) / [ticket](https://github.com/biolds/sosse/issues/6))

## 1.10.0 (2024-07-04)
### Features (5 changes)
- [crawl policies enable/disable, copy](https://gitlab.com/biolds1/sosse/-/commit/6a79a1b8771a935b9ba388722441236000f0e41a) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/109))
- [document hiding](https://gitlab.com/biolds1/sosse/-/commit/2930b03d7ebc97cec2441c5361a9275bc9be9214) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/108) / [ticket](https://github.com/biolds/sosse/issues/5))
- [UI dark theme](https://gitlab.com/biolds1/sosse/-/commit/8c599190a5f1384abeb7e673c72dd756e48ebe25) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/108))
- [Statistics page rework](https://gitlab.com/biolds1/sosse/-/commit/20caec242ae3c9e5fb58ada519542845700ccb4c) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/103))
- [Rest API](https://gitlab.com/biolds1/sosse/-/commit/127f6498efa5cadc83dee8ef74ec34bd3dcafc64) ([merge request](https://gitlab.com/biolds1/sosse/-/merge_requests/102))

## 1.9.0 (2024-03-10)
### Features (2 changes)
- [ignore robots.txt file when it redirects in a loop](biolds1/sosse@882dfc7cb4eea834744cc8c63e20b3eab020f16f) ([merge request](biolds1/sosse!98))
- [CLI command to mass delete documents](biolds1/sosse@b24e64c051b82ec0e0ecc46c70c18eafd3048aaa) ([merge request](biolds1/sosse!84))
### Bug fixes (3 changes)
- [fixes for long upgrade time and slow crawler startup](biolds1/sosse@0f7be42efac1a0b251e6bc6d210ec1897fc5ce3b) ([merge request](biolds1/sosse!100))
- [prevent user creation of Domain settings](biolds1/sosse@a5a9f1a5aa40e6f98a801e98c91f059b1ce37726) ([merge request](biolds1/sosse!95))
- [fix browser mode detection](biolds1/sosse@df3a1fea5ff15a0fe87171dc070fb88b04b5f87d) ([merge request](biolds1/sosse!91))

## 1.8.2 (2024-01-23)
### Bug fixes (2 changes)
- [fix thumbnails deletion when deleting a document](biolds1/sosse@f5a3c984bc0d478d2232bf9a517d5d7ab1c424ca) ([merge request](biolds1/sosse!83))
- [pin working Selenium version](biolds1/sosse@9fcd0eea668e4c301ed1f0b8ea5ad95df512d8a9) ([merge request](biolds1/sosse!89))

## 1.8.1 (2024-01-14)
### Bug fixes (2 changes)
- [fix skipping pages with mimetype to be skipped](biolds1/sosse@b67f2b263b388538251e078d752b6acaee72ef7b) ([merge request](biolds1/sosse!81))
- [work-around to libmagic misidentifying some HTML page as application/javascript](biolds1/sosse@16d37ab9e08a2d10bdd68a67092e87d2f37eb19c) ([merge request](biolds1/sosse!81))

## 1.8.0 (2024-01-10)
### Features (4 changes)
- [HTML pages download with Requests](biolds1/sosse@6eb1eaebe33ecd2f47eab4c4aa291336fd600d7f) ([merge request](biolds1/sosse!79))
- [online status detection to optionally search locally when offline](biolds1/sosse@bab9c400789259ad974d93890ce112d64ccc22de) ([merge request](biolds1/sosse!75))
- [improve page changes detection](biolds1/sosse@7000ba3c99f0bd3c1411f516651e5905d0a574a0) ([merge request](biolds1/sosse!74))
- [add a "starts with" option to excluded urls](biolds1/sosse@241107fcf670ec807678755ef1ac106fe7259a46) ([merge request](biolds1/sosse!67))
### Bug fixes (1 change)
- [avoid recrawling documents after a redirect](biolds1/sosse@c010e05ad95c6c66c0fd9a7aca02ed4815143bbf) ([merge request](biolds1/sosse!78))

## 1.7.0 (2023-11-10)
### Features (4 changes)
- [navigation improvements](biolds1/sosse@36b51d5e5caeefbdfe62aa7f876fef2eb479d78f) ([merge request](biolds1/sosse!60))
- [display the search bar in cached pages](biolds1/sosse@2fe0def9739dc6f56ce0f8aa10df9cd5816c4593) ([merge request](biolds1/sosse!60))
- [set in the Crawl policy when to remove navigation related elements](biolds1/sosse@dc87295f1acda409d357a1b3d180b1e527895d96) ([merge request](biolds1/sosse!57))
- [save dynamic CSS in HTML snapshots](biolds1/sosse@6af4d002b63015350f106db6853c3d87eedb4392) ([merge request](biolds1/sosse!55))
### Bug fixes (4 changes)
- [fix font size on Chrome](biolds1/sosse@bed3ecdc0799fdc3f43f0aafac3bc45abbc16358) ([merge request](biolds1/sosse!60))
- [fix downloading css assets containings special characters](biolds1/sosse@d0095120a4c32420d86cda4e43cb0a0c8efc99ed) ([merge request](biolds1/sosse!55))
- [avoid an infinite loops in particular conditions when a page is self-referencing](biolds1/sosse@ef0c824a543e91606c679668cee9ec31e6c60ad9) ([merge request](biolds1/sosse!55))
- [avoid timing issues during authentication](biolds1/sosse@40224f0e0cb27e52265c697f7d471aafba27d5b7) ([merge request](biolds1/sosse!55))

## 1.6.0 (2023-10-14)
### Features (2 changes)
- [crawler Firefox 🦊 support](biolds1/sosse@093a284d10ef8cb1f878f376a9d04f737b019834) ([merge request](biolds1/sosse!52))
- [Atom and RSS feeds parsing](biolds1/sosse@34e63311406480e7c4bb35d31fb5abeed3ae6cd9) ([merge request](biolds1/sosse!48))

## 1.5.0 (2023-08-29)
### Bug fixes (5 changes)
- [remove html comments from documents](biolds1/sosse@bd871c5cde356846af74e5a36993570ddd6be063) ([merge request](biolds1/sosse!43))
- [handle invalid links correctly](biolds1/sosse@3dd626ccd1ab56b71a07283f494b877903cadfc7) ([merge request](biolds1/sosse!42))
- [fix result heights when thumbnail is enabled](biolds1/sosse@c998fb81113e3582aa472f65124e08e6fa7d00eb) ([merge request](biolds1/sosse!40))
- [fix an exception on links with unknown schemes](biolds1/sosse@42de12cfbc81841627f57a77e52a76e08ffca7ff) ([merge request](biolds1/sosse!41))
- [fix handling <base> element in html snapshots](biolds1/sosse@21602ff4564ac3d3d85f019dd1c83d65a2a6532e) ([merge request](biolds1/sosse!40))

## 1.4.0 (2023-08-24)
### Features (1 change)
- [create pages thumbnails](biolds1/sosse@0f34d0948c78497008932ee4ead05c23134bdaa1) ([merge request](biolds1/sosse!38))
### Bug fixes (2 changes)
- [add missing noreferrer flag to the unknown url page](biolds1/sosse@01d07a682e386fa041438fe597cf6ec061f4b3b0) ([merge request](biolds1/sosse!37))
- [avoid a race condition in HTML assets handling](biolds1/sosse@5fa9d5f8fbed4ef5119f1527479b1a02faf76b40) ([merge request](biolds1/sosse!37))

## 1.3.2 (2023-08-22)
### Bug fixes (2 changes)
- [fix handling some malformed urls](biolds1/sosse@efea7e3d7ced7ae144b935ecd06eaff1381ca5c2)
- [fix the docker build](biolds1/sosse@352de823a096510773fa1cd0232e84d4c931f5f3)

## 1.3.1 (2023-08-21)
### Bug fixes (1 change)
- [fix running with debug disabled](biolds1/sosse@ae4f4acec2eb0ca497d659d9e88a0dbef92c0a94) ([merge request](biolds1/sosse!35))

## 1.3.0 (2023-08-21)
### Features (4 changes)
- [no referrer and open in new tab options for external links](biolds1/sosse@6c701a4782d517c80348642e09f68564f8a9bed3) ([merge request](biolds1/sosse!32))
- [HTML content snapshot](biolds1/sosse@95367eb28a71d197c7533b8935ab0c541c9dfc9f) ([merge request](biolds1/sosse!23))
- [foldable header in screenshots view](biolds1/sosse@fa8247c052099c4242c8d8fe707477b49ef68397) ([merge request](biolds1/sosse!21))
- [Document admin page improvement](biolds1/sosse@ea97cfae49b7e6353d3c61f5aa653d06b5c17109) ([merge request](biolds1/sosse!20))
### Bug fixes (3 changes)
- [update extern links if the target is indexed again afterward](biolds1/sosse@f743e44039d34df1c16958112c7d14cb019b690a) ([merge request](biolds1/sosse!32))
- [fix sameSite cookie option formatting](biolds1/sosse@e4ecfa6e001fd9332795fbb63dbd36459b4a4c4c)
- [force screenshot refresh when they changed](biolds1/sosse@0f04fc7da39e7b33b5cf7ad7e6a5b5fdb7df8117) ([merge request](biolds1/sosse!20))

## 1.2.0 (2023-07-14)
### Features (2 changes)
- [crawling status improvements](biolds1/sosse@848fba81977bf56780430592261bd0847ee52110) ([merge request](biolds1/sosse!18))
- [navigation elements removal](biolds1/sosse@0d9d3582486ed45202359fa5174aadc5bb945d3d) ([merge request](biolds1/sosse!16))
### Bug fixes (1 change)
- [fix screenshots resize](biolds1/sosse@5f6ca3441cd402b5d71ad77598b0e8a17c80dbd6) ([merge request](biolds1/sosse!17))

## 1.1.2 (2023-06-30)
### Bug fixes (1 change)
- [fix database configuration documentation](biolds1/sosse@d10379ffbdfe19bbaef302822110641e9495f75a)

## 1.1.1 (2023-06-29)
### Bug fixes (1 change)
- [misc Bookworm, Docker and Selenium fixes](biolds1/sosse@54fcc7043bfc34a6125fa301d58c08ea02e0b292) ([merge request](biolds1/sosse!12))

## 1.1.0 (2023-06-18)
### Features (3 changes)
- [Debian Bookworm support](biolds1/sosse@b2112e5a0a526e777600499d726002ad62612aac) ([merge request](biolds1/sosse!10))
- [browsable archive on homepage view](biolds1/sosse@f3f2c065f63ada182e0f6154b5586dcae1ea5158) ([merge request](biolds1/sosse!8))
- [automatically follow redirection in cached pages](biolds1/sosse@5d2a40ef0d253a5e47746d25d725794d58216cb2) ([merge request](biolds1/sosse!7))
### Bug fixes (2 changes)
- [fix resolving links when the header has a <base> tag](biolds1/sosse@ff6d4f2d33d6395be87c026c5c9f87c457d5f1a7) ([merge request](biolds1/sosse!6))
- [scroll all elements when taking screenshots](biolds1/sosse@1001d51d41241fb971bde65f5f2fa22e583eff17) ([merge request](biolds1/sosse!5))

## 1.0.1 (2023-05-01)
### Features (1 change)
- [doc improvements](biolds1/sosse@1f2cbcc6f4fc9d537358147aa39e538e1020e9ce)
### Bug fixes (1 change)
- [build the Docker release using pypi packages](biolds1/sosse@40f3d6a7e36784b8a515c3ebda60af67e5ded52e)
